@@ -18,13 +18,13 @@ from ..iostream import BackgroundSocket, IOPubThread, OutStream
 from .constants import INPROCESS_KEY
 from .socket import DummySocket
 
-
 # -----------------------------------------------------------------------------
 # Main kernel class
 # -----------------------------------------------------------------------------
 
 
 class InProcessKernel(IPythonKernel):
+    """An in-process kernel."""
 
     # -------------------------------------------------------------------------
     # InProcessKernel interface
@@ -68,6 +68,7 @@ class InProcessKernel(IPythonKernel):
     stdin_socket = Instance(DummySocket, ())  # type:ignore[assignment]
 
     def __init__(self, **traits):
+        """Initialize the kernel."""
         super().__init__(**traits)
 
         self._underlying_iopub_socket.observe(self._io_dispatch, names=["message_sent"])
@@ -164,6 +165,7 @@ class InProcessKernel(IPythonKernel):
 
 
 class InProcessInteractiveShell(ZMQInteractiveShell):
+    """An in-process interactive shell."""
 
     kernel: InProcessKernel = Instance(
         "ipykernel.inprocess.ipkernel.InProcessKernel", allow_none=True
